pub struct Vulnerability {
pub dependency: Dependency,
pub id: VulnerabilityID,
pub summary: Option<String>,
pub description: Option<String>,
pub link: Option<DisplaySafeUrl>,
pub fix_versions: Vec<Version>,
pub aliases: Vec<VulnerabilityID>,
pub published: Option<Timestamp>,
pub modified: Option<Timestamp>,
}Expand description
A vulnerability within a dependency.
Fields
dependency: DependencyThe dependency that is vulnerable.
id: VulnerabilityIDThe unique identifier for the vulnerability.
summary: Option<String>A short, human-readable summary of the vulnerability, if available.
description: Option<String>A full-length description of the vulnerability, if available.
link: Option<DisplaySafeUrl>A link to more information about the vulnerability, if available.
fix_versions: Vec<Version>Zero or more versions that fix the vulnerability.
aliases: Vec<VulnerabilityID>Zero or more aliases for this vulnerability in other databases.
published: Option<Timestamp>The timestamp when this vulnerability was published, if available.
modified: Option<Timestamp>The timestamp when this vulnerability was last modified, if available.
Implementations
Sourceimpl Vulnerability
impl Vulnerability
Sourcepub fn matches(&self, id: &VulnerabilityID) -> bool
pub fn matches(&self, id: &VulnerabilityID) -> bool
Returns true if any of this vulnerability’s identifiers (primary ID or aliases) match the given ID.
Sourcepub fn best_id(&self) -> &VulnerabilityID
pub fn best_id(&self) -> &VulnerabilityID
Pick the subjectively “best” identifier for this vulnerability. For our purposes we prefer PYSEC IDs, then GHSA, then CVE, then whatever primary ID the vulnerability came with.